# Changelog

## griffe-pydantic Insiders

### 1.0.1 <small>May 27, 2024</small> { id="1.0.1" }

- Depend on Griffe 0.38 minimum
- Detect inheritance when `BaseModel` is imported from `pydantic.main`
- Don't crash on keyword arguments in `@field_validator` decorators

### 1.0.0 <small>March 20, 2023</small> { id="1.0.0" }

- Support Pydantic v2
- Support both static and dynamic analysis
- Detect when classes inherit from Pydantic models

### 1.0.0a0 <small>July 13, 2023</small> { id="1.0.0a0" }

- Release first Insiders version (alpha)
